.\" man v3.0 92/7/27 rosenkra
.TH MAN 1
.SH NAME
man \- read online documentation
.SH SYNOPSIS
.\" man [- [-ul]] [-s sect[subs]] [-M path] [-m path] [-e] [sect[subs]] name ...
.B man
.RB [ \-
.RB [ \-ul ]]
.RB [ \-s
.IR sect [ subs ]]
.RB [ \-M
.IR path ]
.RB [ \-m
.IR path ]
.RB [ \-e ]
.RI [ sect [ subs ]]
.IR name ...
.br
.\" man -f file
.B man
.B \-f
.IR file ...
.br
.\" man -k keyword...
.B man
.B \-k
.IR keyword ...
.SH DESCRIPTION
The
.B man
command finds and displays information in the online documentation set.
When the standard output is a terminal,
.B man
pipes its output through
.BR less (1)
or the name of the command specified with the MANPAGER or PAGER environment
variables.
.SH OPTIONS
The following command line options are recognized: 
.IP \fB\-\fR
Pipes the output through
.BR cat (1)
rather than
.BR less (1)
or PAGER.
.IP \fB\-ul\fR
Use
.BR ul (1)
rather than
.BR cat (1).
.IP "\fB\-M\fR \fIpath\fR"
Specifies a directory tree in which to search.
By default,
.B man
searches in d:\\usr\\man or the directory specified by the
MANPATH environment variable, the standard location for online
documentation.
This option assumes
.I path
is the root of a \*(lqnormal\*(rq directory structure.
.IP "\fB\-m\fR \fIpath\fR"
Specifies a directory in which to search.
This option does not use a directory tree.
Files are searched only in the directory specified by
.IR path .
This option is useful for debugging new manpages.
For example, assuming you are working on a manpage
named \*(lqmycmd.1\*(rq, you can do this:
.sp
.RS
man -m . 1 mycmd
.RE
.IP \fB\-e\fR
Find every manpage concerning the given
.I name
regardless of section.
It is expected that a \*(lqnormal\*(rq exit from the pager
will result in an exit status of 0 (in which case the search is continued
in other sections).
An \*(lqabnormal\*(rq exit should result in a nonzero exit status
and the search is then terminated.
.IP "\fB\-s\fR \fIsect\fR[\fIsubsect\fR]"
Specifies a
.I section
and
.I subsection
similar to the 4.2 BSD UNIX Programmer's Manual (as explained below)
in which to search.
If no
.I section
is specified,
.B man
searches through all of the sections.
Example:  \*(lqman -s 3s fopen\*(rq.
.IP \fIsect\fR
As an alternative to
.BR \-s ,
you can specify the section (and optional subsection) as the first
argument.
Example:  \*(lqman 3s fopen\*(rq.
.IP \fIname\fR
Searches for documentation files associated with the specified
.IR name .
.IP "\fB\-f\fR \fIname\fR"
Displays a one line synopsis of each online documentation file whose
names match the specified word (equivalent to the
.BR whatis (1)
command).
For example, \*(lqman -f chmod\*(rq will give entries for both
.BR chmod (1)
and
.BR chmod (2).
Note that
.B man
invokes
.BR whatis (1)
in this case, so it should be found in the path (see ENVIRONMENT).
.IP "\fB\-k\fR \fIkeyword\fR"
Displays a one line synopsis of each online documentation file whose name
or description contains the specified
.I keyword
(equivalent to the
.BR apropos (1)
command).
Note that
.B man
invokes
.BR apropos (1)
in this case, so it should be found in the path (see ENVIRONMENT).
.SH ENVIRONMENT
The following environment variables are recognized:
.IP MANPATH,MANDIR
Location of main manual direcotry, where subdirectories are to be found.
.B Man
uses (in order of priority) the path specified with
.BR \-M ,
the MANPATH specified, or the built-in default (c:\\man).
.IP MANPAGER
Name of prefered pager.
Use this pager if you have compressed manpages (see
.IR manpager (1)).
.B Man
will use first MANPAGER, if found, then PAGER, if found.
If neither are found, it uses c:\\bin\\less.ttp.
.IP PAGER
Name of secondary pager to replace
.IR less (1).
Use this if you do not have manpages generated with font changes (see
.IR nroff (1)).
Either MANPAGER or PAGER should be defined.
The search order is MANPAGER then PAGER.
.\" .IP BINDIR
.\" Alternate location to find all necessary executables.
.\" The default is c:\\bin.
.\" You need
.\" .BR less (1),
.\" .BR cat (1),
.\" and
.\" .BR ul (1)
.\" at a minimum.
.\" .IP TMPDIR
.\" Place to put temporary files, if necessary.
.\" Default is g:\\tmp.
.\" Make it a ramdisk partition, if you have one.
.\" So far this is not used.
.SH "SECTION NAMES"
The "sections" of the manual are:
.sp
.nf
Sect	Section Name	Description
----	-------------	--------------------------------------
0	General		overview of features and documentation
1	Commands	user commands
2	System Calls	low-level system library calls (C)
3	Library Calls	standard user calls (C)
4	Special Files	special system files and hardware
5	File formats	things like arc(1) file formats
6	Games		games manual
7	Miscellaneous	miscellaneous information
8	Administration	system administration commands
.fi
.sp
In addition,
.B man
recognizes the following section names:
.sp
.nf
local		files specific to local system
new		files added since current software release
old		files from previous software release
gnu		GNU files
paper		misc formal papers
doc		misc documentation
.fi
.PP
The search order, if no section is specified, is:
.sp
.nf
108234576
.fi
.PP
In addition to sections, there are a number of subsections possible,
though these files do not reside in a special directory.
The subsection name is simply appended to the file name.
Example:
\*(lqfopen.3s\*(rq resides in $MANPATH\\man3, the section is \*(lq3\*(rq
(libraries) and the subsection is \*(lqs\*(rq, stdio.
Here is the subsection search order for subsections in each section
(the square brackets mean a choice of each character contained in them,
in that order):
.sp
.nf
man1\\*.1[tcgesla]	util & text, com, graphics, edit, shell,
			lang, archival
man0\\*.0
man8\\*.8[s]		util & system
man2\\*.2[gbx]		system & gemdos, bios, xbios
man3\\*.3[msvcxg]	C lib & math, stdio, sysV, compat,
			extra, gem(aes/vdi)
man4\\*.4[dkvscm]	general & disk, keyboard, video, sound,
			chips, memory
man5\\*.5
man7\\*.7
man6\\*.6
.fi
.SH NOTES
To save disk space, you can "source" other files by including the
.BR nroff (1)
directive \*(lq.so\*(rq in a file as the first line.
In this case, the first line should start with .so followed by at least
one space, then the file to use instead of the actual manpage.
For example, the manpage for feof.3s (in $MANPATH\\man3) contains the single
line:
.sp
.nf
	.so man3\\ferror.3s
.fi
.sp
which will cause
.B man
to display the contents of \*(lqferror.3s\*(rq instead.
Note the relative path (relative to MANPATH, by default d:\\usr\\man).
In this way, numerous manpages can refer to a single (larger) file.
Do not compress files with source lines as
.B man
only checks for this line if it finds a file which is not compressed.
Note that you can only compress files for viewing with
.BR manpager (1)
and must set the MANPAGER environment variable as well.
.SH FILES
.nf
d:\\usr\\man		root of standard manual page directory tree
d:\\usr\\man\\man*\\*	manual entries
d:\\usr\\man\\whatis	table of contents and keyword database
.fi
.SH "SEE ALSO"
apropos(1), cat(1), less(1), manpager(1), nroff(1),
whatis(1), whatisin(1), whereis(1), man(7)
.SH AUTHOR
Bill Rosenkranz
.br
rosenkra@convex.com
.SH VERSION
man v3.0 92/7/27 rosenkra
