.\" @(#) manpager.man 1.4 91/1/27 rosenkra
.TH MANPAGER 1
.SH NAME
manpager \- a pager for man which handles font changes
.SH SYNOPSIS
.\" manpager [ -z ] [ -s | -fun ] file
.B manpager
[
.B \-z
] [
.B \-s
|
.B \-fun
]
.I file
.SH DESCRIPTION
.B Manpager
is a program similar to
.BR less (1),
which allows backwards movement in the file as well as forward movement.
It was written to view manpages formatted with
.BR nroff (1)
which has the ability to generate the proper escape sequences.
It is not as comprehensive as
.B less
but provides most of the functionality.
.B Manpager
does provide a significant advantage over
.B less
in that it will interpret certain escape sequences (see below), turning
them into font changes so that
.B bold
and
.I italic
(or underline)
text in manpages can be viewed.
.PP
.B Manpager
works interactively.
It can, however, be used as a filter to remove the escape sequences it finds
if it detects that stdout is not the console.
This occurs if output of
.B manpager
is redirected as in:
.sp
.nf
	manpager file >newfile
.fi
.sp
All input on stdin is ignored in this mode.
.PP
However, when
.B manpager
is invoked automatically by
.BR man (1),
it is placed in interactive mode.
Like
.BR less (1),
interactive commands are based on both more and vi.
Some commands may be preceeded by a decimal number, called N in the
descriptions below.
The number is used by some commands, as indicated.
Commands not using N ignore it.
.PP
.B Manpager
can also handle compressed files, i.e. those compressed with
.BR compress (1),
if the
.B \-z
option is given.
.SH OPTIONS
The following command line options are recognized:
.IP \fB\-z\fR
Decompress input file while reading.
It is assumed that the file was compressed with 
.BR compress (1).
.IP \fB\-s\fR
Use standard system font.
No internal font switching occurs, regardless of escapes sequences.
Non printable characters are represented by an octal string:
.sp
.RS
\\xxx
.RE
.sp
where \*(lqxxx\*(rq is the octal representation of the ASCII character.
This makes
.B manpager
function more or less like
.BR less (1).
.IP \fB\-fun\fR
Use an alternate (internal) font for fun!
.PP
Note that
.B \-s
and
.B \-fun
are mutually exclusive.
.SH COMMANDS
.\" In the following descriptions, ^X means control-X.
.\" ESC stands for the ESCAPE key; for example ESC-v means the two
.\" character sequence "ESCAPE", then "v".
Commands are broken down into 3 categories: those for movement within the
file, those for searching for strings, and those for control.
The following commands are available when
.B manpager
is running interactively:
.SS "Commands For Movement:"
.nf
\fBg\fR          go to line N (default 1)
\fBG\fR          go to last line
\fBf\fR, \fBspace\fR   forward N screens (default 1)
\fBb\fR          backward N screens (default 1)
\fBd\fR          forward N half screens (default 1)
\fBu\fR          backward N half screen (default 1)
\fBj\fR,\fBe\fR,\fBCR\fR     forward N lines (default 1)
\fBk\fR,\fBy\fR        backward N lines (default 1)
.fi
.SS "Commands For Searching:"
.nf
\fB/\fIstring\fR    search forward for string (no regular expressions)
\fB?\fIstring\fR    search backward for string
\fBn\fR          repeat last search (backward or forward)
.fi
.SS "Other Commands:"
.nf
\fBq\fR,\fBQ\fR        quit
\fBr\fR          repaint screen
\fBh\fR,\fBH\fR        help
\fB=\fR          show file name and position
\fBV\fR          show version
.fi
.PP
The commands
.BR g ,
.BR f ,
.BR b ,
.BR d ,
.BR u ,
.BR j ,
and
.B k
all accept optional numerical prefixes, N.
To change their defaults, enter a number, then the command.
For example, enter \*(lq22g\*(rq to go to line 22 or \*(lq2f\*(rq to
advance 2 screens.
.SH "ESCAPES AND FONTS"
Currently, the fonts for
.B manpager
reside in the program itself and are only available for monochrome.
The fonts are changed on the fly as escape sequences are read, and replace
the system 8x16 font only.
.PP
The escape sequences for the fonts are as follows ("\\E" means the ESCAPE
character):
.sp
.nf
	\\E[9m		begin using alternate char set
	\\E[8m		begin using small char set
	\\E[7m		enter standout mode (reverse video)
	\\E[4m		enter undeline mode
	\\E[1m		enter bold mode
	\\E[m or \\E[0m	cancel all modes (normal)
.fi
.sp
These escape sequences are consistent with vt100 or ANSI terminal behavior,
except the alternate and small character sets.
.SH NOTES
For more information, see
.BR nroff (1).
.SH BUGS
Currently works in monochrome only.
.sp
Uses Line A to change fonts, so it may not work on the TT.
.sp
Should be able to load fonts.
Maybe next version.
.SH "SEE ALSO"
less(1), more(1), man(1), nroff(1)
.SH AUTHOR
Bill Rosenkranz
.br
rosenkra@convex.com
.SH VERSION
manpager v1.4 91/1/27
.EX
